powfacpy.PFStringManipuilation
==============================

.. currentmodule:: powfacpy

.. autoclass:: PFStringManipuilation

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~PFStringManipuilation.__init__
      ~PFStringManipuilation.delete_classes
      ~PFStringManipuilation.format_full_path
      ~PFStringManipuilation.handle_path
      ~PFStringManipuilation.replace_between_characters
   
   

   
   
   